MessagePatternDefinition

Struct MessagePatternDefinition 

pub struct MessagePatternDefinition { /* private fields */ }
Framework-neutral message pattern handler definition.

Implementations

Source

impl MessagePatternDefinition

pub fn request<H, Fut, R>( pattern: impl Into<String>, handler: H, ) -> Result<Self>
where H: Fn(TransportMessage) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<R>> + Send + 'static, R: IntoTransportReply + Send + 'static,

pub fn request_scoped<F, H, Fut, R>( pattern: impl Into<String>, factory: F, ) -> Result<Self>
where F: Fn(&ModuleRef) -> Result<H> + Send + Sync + 'static, H: Fn(TransportMessage) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<R>> + Send + 'static, R: IntoTransportReply + Send + 'static,

Build a request-response pattern whose handler is created from the current message dispatch’s dependency-injection scope.

pub fn event<H, Fut>(pattern: impl Into<String>, handler: H) -> Result<Self>
where H: Fn(TransportMessage) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<()>> + Send + 'static,

pub fn event_scoped<F, H, Fut>( pattern: impl Into<String>, factory: F, ) -> Result<Self>
where F: Fn(&ModuleRef) -> Result<H> + Send + Sync + 'static, H: Fn(TransportMessage) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<()>> + Send + 'static,

Build an event pattern whose handler is created from the current message dispatch’s dependency-injection scope.

pub fn request_json<T, H, Fut, R>( pattern: impl Into<String>, handler: H, ) -> Result<Self>
where T: DeserializeOwned + Send + 'static, H: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<R>> + Send + 'static, R: Serialize + Send + 'static,

pub fn request_validated_json<T, H, Fut, R>( pattern: impl Into<String>, handler: H, ) -> Result<Self>
where T: DeserializeOwned + Validate + Send + 'static, H: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<R>> + Send + 'static, R: Serialize + Send + 'static,

pub fn event_json<T, H, Fut>( pattern: impl Into<String>, handler: H, ) -> Result<Self>
where T: DeserializeOwned + Send + 'static, H: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<()>> + Send + 'static,

pub fn event_validated_json<T, H, Fut>( pattern: impl Into<String>, handler: H, ) -> Result<Self>
where T: DeserializeOwned + Validate + Send + 'static, H: Fn(T) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<()>> + Send + 'static,

pub fn pattern(&self) -> &str

pub fn kind(&self) -> MessagePatternKind

pub fn is_scoped(&self) -> bool

Return whether this pattern constructs its handler from each dispatch scope.

pub fn module_name(&self) -> Option<&str>

pub fn metadata(&self) -> &BTreeMap<String, Value>

pub fn metadata_value(&self, key: &str) -> Option<&Value>

pub fn with_metadata<V>(self, key: impl Into<String>, value: V) -> Result<Self>
where V: Serialize,

pub fn with_metadata_value(self, key: impl Into<String>, value: Value) -> Self

pub fn with_pipe<P>(self, pipe: P) -> Self
where P: TransportPipe,

pub fn with_guard<G>(self, guard: G) -> Self
where G: TransportGuard,

pub fn with_execution_guard<G>(self, guard: G) -> Self
where G: Guard,

pub fn with_interceptor<I>(self, interceptor: I) -> Self

pub fn with_execution_interceptor<I>(self, interceptor: I) -> Self

pub fn with_filter<F>(self, filter: F) -> Self

pub fn with_catch_filter<I, F>(self, kinds: I, filter: F) -> Self

pub fn with_validation(self) -> Self

pub fn with_validation_options(self, options: ValidationOptions) -> Self

pub fn without_validation(self) -> Self

pub fn with_payload_validation<T>(self) -> Self
where T: DeserializeOwned + Validate + 'static,

pub fn with_payload_validation_options<T>( self, options: ValidationOptions, ) -> Self

pub async fn dispatch( &self, message: TransportMessage, ) -> Result<Option<TransportReply>>