ProviderDefinition

Struct ProviderDefinition 

pub struct ProviderDefinition { /* private fields */ }
A provider registration, similar to a Nest provider entry.

Implementations

Source

impl ProviderDefinition

pub fn singleton<T>(value: T) -> Self
where T: Send + Sync + 'static,

pub fn named_singleton<T>(token: impl Into<String>, value: T) -> Self
where T: Send + Sync + 'static,

pub fn from_arc<T>(value: Arc<T>) -> Self
where T: Send + Sync + 'static,

pub fn named_from_arc<T>(token: impl Into<String>, value: Arc<T>) -> Self
where T: Send + Sync + 'static,

pub fn factory<T, F>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<T> + Send + Sync + 'static,

pub fn factory_arc<T, F>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<Arc<T>> + Send + Sync + 'static,

pub fn named_factory<T, F>(token: impl Into<String>, factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<T> + Send + Sync + 'static,

pub fn named_factory_arc<T, F>(token: impl Into<String>, factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<Arc<T>> + Send + Sync + 'static,

pub fn async_factory<T, F, Fut>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(ModuleRef) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<T>> + Send + 'static,

pub fn async_factory_arc<T, F, Fut>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(ModuleRef) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Arc<T>>> + Send + 'static,

pub fn named_async_factory<T, F, Fut>( token: impl Into<String>, factory: F, ) -> Self
where T: Send + Sync + 'static, F: Fn(ModuleRef) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<T>> + Send + 'static,

pub fn named_async_factory_arc<T, F, Fut>( token: impl Into<String>, factory: F, ) -> Self
where T: Send + Sync + 'static, F: Fn(ModuleRef) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Arc<T>>> + Send + 'static,

pub fn injectable<T>() -> Self
where T: FromModuleRef,

pub fn named_injectable<T>(token: impl Into<String>) -> Self
where T: FromModuleRef,

pub fn alias<T>(target: ProviderToken) -> Self
where T: Send + Sync + 'static,

pub fn named_alias(token: impl Into<String>, target: ProviderToken) -> Self

pub fn transient<T, F>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<T> + Send + Sync + 'static,

pub fn transient_arc<T, F>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<Arc<T>> + Send + Sync + 'static,

pub fn named_transient<T, F>(token: impl Into<String>, factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<T> + Send + Sync + 'static,

pub fn named_transient_arc<T, F>(token: impl Into<String>, factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<Arc<T>> + Send + Sync + 'static,

pub fn transient_injectable<T>() -> Self
where T: FromModuleRef,

pub fn named_transient_injectable<T>(token: impl Into<String>) -> Self
where T: FromModuleRef,

pub fn request_scoped<T, F>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<T> + Send + Sync + 'static,

pub fn request_scoped_arc<T, F>(factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<Arc<T>> + Send + Sync + 'static,

pub fn named_request_scoped<T, F>(token: impl Into<String>, factory: F) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<T> + Send + Sync + 'static,

pub fn named_request_scoped_arc<T, F>( token: impl Into<String>, factory: F, ) -> Self
where T: Send + Sync + 'static, F: Fn(&ModuleRef) -> Result<Arc<T>> + Send + Sync + 'static,

pub fn request_scoped_injectable<T>() -> Self
where T: FromModuleRef,

pub fn named_request_scoped_injectable<T>(token: impl Into<String>) -> Self
where T: FromModuleRef,

pub fn app_guard<T>() -> Self
where T: FromModuleRef + Guard,

Register an injectable provider as an application-wide HTTP guard.

pub fn app_pipe<T>() -> Self
where T: FromModuleRef + Pipe,

Register an injectable provider as an application-wide HTTP pipe.

pub fn app_interceptor<T>() -> Self

Register an injectable provider as an application-wide HTTP interceptor.

pub fn app_filter<T>() -> Self

Register an injectable provider as an application-wide HTTP exception filter.

pub fn app_websocket_guard<T>() -> Self

Register an injectable provider as an application-wide WebSocket guard.

pub fn app_websocket_pipe<T>() -> Self

Register an injectable provider as an application-wide WebSocket pipe.

pub fn app_websocket_interceptor<T>() -> Self

Register an injectable provider as an application-wide WebSocket interceptor.

pub fn app_websocket_filter<T>() -> Self

Register an injectable provider as an application-wide WebSocket exception filter.

pub fn app_transport_guard<T>() -> Self

Register an injectable provider as an application-wide transport guard.

pub fn app_transport_pipe<T>() -> Self

Register an injectable provider as an application-wide transport pipe.

pub fn app_transport_interceptor<T>() -> Self

Register an injectable provider as an application-wide transport interceptor.

pub fn app_transport_filter<T>() -> Self

Register an injectable provider as an application-wide transport exception filter.

pub fn with_app_guard<T>(self) -> Self
where T: Guard,

Mark this provider as an application-wide HTTP guard.

pub fn with_app_pipe<T>(self) -> Self
where T: Pipe,

Mark this provider as an application-wide HTTP pipe.

pub fn with_app_interceptor<T>(self) -> Self
where T: Interceptor,

Mark this provider as an application-wide HTTP interceptor.

pub fn with_app_filter<T>(self) -> Self
where T: ExceptionFilter,

Mark this provider as an application-wide HTTP exception filter.

pub fn with_app_websocket_guard<T>(self) -> Self
where T: WebSocketGuard,

Mark this provider as an application-wide WebSocket guard.

pub fn with_app_websocket_pipe<T>(self) -> Self
where T: WebSocketPipe,

Mark this provider as an application-wide WebSocket pipe.

pub fn with_app_websocket_interceptor<T>(self) -> Self

Mark this provider as an application-wide WebSocket interceptor.

pub fn with_app_websocket_filter<T>(self) -> Self

Mark this provider as an application-wide WebSocket exception filter.

pub fn with_app_transport_guard<T>(self) -> Self
where T: TransportGuard,

Mark this provider as an application-wide transport guard.

pub fn with_app_transport_pipe<T>(self) -> Self
where T: TransportPipe,

Mark this provider as an application-wide transport pipe.

pub fn with_app_transport_interceptor<T>(self) -> Self

Mark this provider as an application-wide transport interceptor.

pub fn with_app_transport_filter<T>(self) -> Self

Mark this provider as an application-wide transport exception filter.

pub fn with_scope(self, scope: ProviderScope) -> Self

pub fn with_dependencies<I>(self, dependencies: I) -> Self

Declare the dependencies captured by this provider factory.

pub fn depends_on<T>(self) -> Self
where T: Send + Sync + 'static,

Add one required typed dependency to this provider factory.

pub fn depends_on_named(self, token: impl Into<String>) -> Self

Add one required named dependency to this provider factory.

pub fn with_dependency(self, dependency: ProviderDependency) -> Self

Add one dependency while retaining previously declared metadata.

pub fn with_on_module_init<T>(self) -> Self

pub fn with_on_application_bootstrap<T>(self) -> Self

pub fn with_on_module_destroy<T>(self) -> Self

pub fn with_before_application_shutdown<T>(self) -> Self

pub fn with_on_application_shutdown<T>(self) -> Self

pub fn token(&self) -> &ProviderToken

pub fn scope(&self) -> ProviderScope

pub fn dependencies(&self) -> Option<&[ProviderDependency]>

Declared dependency metadata, or None for an opaque factory.